# Howitzer

Research and data analysis hub for various topics.

Eventualy providing datasets as well as tools for them.

## Guid

### Unit Tests

`python -m unittest discover -p "test_*.py"`

### Install Local

`pip install -e .`

### Build

`python setup.py sdist bdist_wheel`

### Publish

`twine upload dist/*`
